from openpyxl import load_workbook

# データの入力規則
from openpyxl.worksheet.datavalidation import DataValidation

wb = load_workbook('テスト.xlsx')
ws = wb.active

# DataValidation(type=入力の種類,
#                operator=条件,
#                formula1=値, formula2=値,
#                allow_blank=[空白を無視する]場合はTrue)
# ※ [空白を無視する]は分かりにくいので、基本Flase か 省略

# -- type(入力の種類) --
# whole : 整数 / time : 時刻 / date : 日付 / decimal : 小数点
# textLength : 長さ指定文字列
# list : リスト
# custom : ユーザー設定

# -- operator(条件) --
# greaterThan: より大きい / greaterThanOrEqual: 以上
# lessThan: より小さい / lessThanOrEqual: 以下
# equal: 等しい / notEqual: 等しくない
# between: 値の間 / notBetween: 値の間以外

# リスト
validation = DataValidation(type='list', formula1='"準備,対応,完了"')
validation.add('A1:A3')
ws.add_data_validation(validation)

# ユーザー設定
validation = DataValidation(type='custom', formula1='=OR(B1="A",B1="")')
validation.add('B1')
ws.add_data_validation(validation)

# 整数 10~20 → Excelを見ながらがイメージしやすい
validation = DataValidation(type='whole', operator='between',
                            formula1='10', formula2='20')
validation.add('C1:C3')
validation.promptTitle = '注意'
validation.prompt = '10~20の数字'
validation.errorTitle = 'だめです'
validation.error = '10~20の数字を入力してね'
validation.errorStyle = 'warning'
ws.add_data_validation(validation)

wb.save('出力.xlsx')
